@@ -152,7 +152,7 @@ void crossover(double ***population, double *paras, int agentID){
 void mutation(double ***population, double *paras, int agentID){
     
     int agent, row, col, start_col, col_check, pop_size, ROWS, COLS;
-    int col_start_other, col_start_self;
+    int col_start_other, col_start_self, mu_magnitude;
     double do_mutation, half_pr, pr;
 
     pop_size        = (int) paras[21];
@@ -174,10 +174,12 @@ void mutation(double ***population, double *paras, int agentID){
             for(col = start_col; col < COLS; col++){
                 do_mutation = runif(0,1);
                 if( do_mutation < half_pr){
-                    population[row][col][agent]--;
+                    mu_magnitude                 = get_rand_int(1, 10);
+                    population[row][col][agent] -= mu_magnitude;
                 }
                 if( do_mutation > (1 - half_pr) ){
-                    population[row][col][agent]++;
+                    mu_magnitude                 = get_rand_int(1, 10);
+                    population[row][col][agent] += mu_magnitude;
                 }
                 if( population[row][col][agent] < 0 ){
                     population[row][col][agent] *= -1;    
@@ -444,7 +446,7 @@ void sum_array_layers(double ***array, double **out, int get_mean,
                         out[row][col] += array[row][col][layer];
                     }
                 }
-            }                
+            } 
         }
     }
 }
@@ -453,32 +455,16 @@ void sum_array_layers(double ***array, double **out, int get_mean,
  * This function updates an action based on the change in costs & paras
  *     old_cost: The old cost of an action, as calculated in policy_to_counts
  *     new_cost: The new cost of an action, as calculated in policy_to_counts
+ *     old_act: Old action count
  *     paras: Vector of global parameters
- *     agent_array: The agent array
  * ========================================================================== */
-int new_act(double old_cost, double new_cost, double old_act, double *paras,
-            double **agent_array){
+int new_action(double old_cost, double new_cost, double old_act){
     
-    int total_acts;
-    double users, acts_per_user, total_cost;
-    double budget_for_act, mgr_budget, min_cost;
+    double new_act;
+  
+    new_act = old_act * (old_cost / new_cost);
     
-    users        = paras[54] - 1;      /* Minus one for the manager */
-    min_cost     = paras[96];          /* Minimum cost of an action */
-    mgr_budget   = agent_array[0][16]; /* Manager's total budget    */
-    
-    total_cost    = 0.0;
-    if(old_cost < mgr_budget){
-        total_cost    = old_act * old_cost; /* Total cost devoted to action */
-    }
-
-    budget_for_act = (total_cost / users);  /* Cost devoted per user */
-
-    /* Calculate how many actions to expect per user, then total actions */
-    acts_per_user  = budget_for_act / (new_cost + min_cost);
-    total_acts     = (double) users * acts_per_user;
-
-    return(total_acts);
+    return(new_act);
 }
 
 /* =============================================================================
@@ -486,7 +472,7 @@ int new_act(double old_cost, double new_cost, double old_act, double *paras,
  *     population: The population array of agents in the genetic algorithm
  *     merged_acts: The action 2D array of summed elements across 3D ACTION
  *     agent: The agent (layer) in the population being simulated
- *     merged_costs: The mean cost paid for each element in the ACTION array
+ *     merged_costs: The total cost paid for each element in the ACTION array
  *     act_change: The array of predicted new actions given new costs
  *     action_row: The row where the action and old costs are located
  *     manager_row: The row where the new costs from the manager are located
@@ -495,26 +481,33 @@ int new_act(double old_cost, double new_cost, double old_act, double *paras,
  * ========================================================================== */
 void policy_to_counts(double ***population, double **merged_acts, int agent,
                       double **merged_costs, double **act_change, 
-                      int action_row, int manager_row, double *paras,
-                      double **agent_array){
+                      int action_row, int manager_row, double *paras, int gen){
     
     int col, COLS;
-    double old_cost, new_cost, old_act, new_action;
+    double old_cost, new_cost, old_act, new_act;
     
     COLS   = (int) paras[69];
     
     for(col = 7; col < COLS; col++){
         old_cost    = merged_costs[action_row][col];
-        new_cost    = population[manager_row][col][agent];
+        new_cost    = old_cost;
+        if(new_cost < merged_costs[0][0]){
+            new_cost    = population[manager_row][col][agent];
+        }
         if(new_cost <= 0){
             new_cost = 1;
             population[manager_row][col][agent] = new_cost;
         }
         
-        old_act     = merged_acts[action_row][col];
-        new_action  = new_act(old_cost, new_cost, old_act, paras, agent_array);
-
-        act_change[action_row][col] = new_action;
+        old_act  = merged_acts[action_row][col];
+        new_act  = new_action(old_cost, new_cost, old_act);
+        
+        act_change[action_row][col] = new_act;
+        /*
+        if(col == 8 && action_row == 0){
+            printf("%d\t%f\t%f\t%f\t%f\t%f\n", gen, old_cost, new_cost, old_act, new_act, act_change[0][8]);       
+        }
+         */
     }
 }
 
@@ -532,7 +525,7 @@ void policy_to_counts(double ***population, double **merged_acts, int agent,
  * ========================================================================== */
 void manager_fitness(double *fitnesses, double ***population, double **jaco,
                      double **agent_array, int **interact_table, int agentID, 
-                     double ***COST, double ***ACTION, double *paras){
+                     double ***COST, double ***ACTION, double *paras, int gen){
     
     int agent, i, j, m_lyr, action_row, manager_row, type1, type2, type3;
     int pop_size, int_num, ROWS, COLS;
@@ -566,17 +559,27 @@ void manager_fitness(double *fitnesses, double ***population, double **jaco,
     }
     
     sum_array_layers(ACTION, merged_acts, 0, paras, agent_array, 0);
-    sum_array_layers(COST,  merged_costs, 1, paras, agent_array, 1);
+    sum_array_layers(COST,  merged_costs, 1, paras, agent_array, 0);
     
     for(i = 0; i < ROWS; i++){ /* Actions > 0 to respond to possible change */
         for(j = 7; j < COLS; j++){
             merged_acts[i][j] += paras[95];
+            /* printf("%f\t",merged_costs[i][j]);*/
         }
+        /* printf("\n"); */
     }
-    
+/*
+    printf("\n");
+  */      
     max_dev = 0;
     for(agent = 0; agent < pop_size; agent++){
         for(action_row = 0; action_row < int_num; action_row++){
+            
+            
+            
+            
+            
+            
             count_change[action_row] = 0; 
             utils[action_row]        = 0; 
             manager_row              = 0;
@@ -591,8 +594,7 @@ void manager_fitness(double *fitnesses, double ***population, double **jaco,
                 manager_row++;
             }
             policy_to_counts(population, merged_acts, agent, merged_costs, 
-                             act_change, action_row, manager_row, paras,
-                             agent_array);
+                             act_change, action_row, manager_row, paras, gen);
             foc_effect  = 0.0;
             foc_effect  += (paras[74] * paras[88] * act_change[action_row][7]);
             foc_effect  += (paras[75] * paras[89] * act_change[action_row][8]);
@@ -603,12 +605,28 @@ void manager_fitness(double *fitnesses, double ***population, double **jaco,
                 count_change[i] += foc_effect * jaco[action_row][i];
             }
             utils[action_row] = ACTION[manager_row][4][m_lyr];
+        
+        
+        /*
+            if(action_row == 0){
+                printf("%d\t%d\t%f\t%f\t%f\t%f\t%f\t", gen, agent, utils[0],
+                       act_change[0][8], foc_effect,
+                       count_change[0], jaco[0][0]);
+            }
+          */  
+            
+            
         }
         change_dev = 0;
         for(i = 0; i < int_num; i++){
             change_dev += (count_change[i]-utils[i])*(count_change[i]-utils[i]);
         }
+        if(change_dev > max_dev){
+            max_dev = change_dev;
+        }
         dev_from_util[agent] = change_dev;
+        
+        
     }
     for(agent = 0; agent < pop_size; agent++){
         fitnesses[agent] = max_dev - dev_from_util[agent];
@@ -844,7 +862,8 @@ void ga(double ***ACTION, double ***COST, double **AGENT, double **RESOURCES,
         if(managing == 1){
             apply_min_costs(POPULATION, paras, agentID);
             manager_fitness(fitnesses, POPULATION, JACOBIAN, AGENT, lookup, 
-                            agentID, COST, ACTION, paras); 
+                            agentID, COST, ACTION, paras, gen);
+            /*      printf("%d\t%f\t%f\n", gen, POPULATION[2][4][0], POPULATION[2][8][0]);   */
         }else{
             strategy_fitness(AGENT, POPULATION, paras, fitnesses, JACOBIAN, 
                              lookup); 
@@ -863,7 +882,7 @@ void ga(double ***ACTION, double ***COST, double **AGENT, double **RESOURCES,
 
         gen++;
     }
-    
+ 
     for(row = 0; row < xdim; row++){
         for(col = 0; col < ydim; col++){
             ACTION[row][col][agent] = POPULATION[row][col][most_fit];  
